@@ -58,7 +58,7 @@ class PeerManager:
         # self.address = self.socket.getsockname() # TODO
         
         self.logger = logging.getLogger("TO " + str(self.peer_ip) + ":" + str(self.peer_port))
-        self.logger.setLevel(options.get("debug-level", logging.DEBUG))
+        self.logger.setLevel(options.get("debug_level", logging.DEBUG))
         self.logger.debug("__init__")
                 
         self.metainfo = metainfo
@@ -848,7 +848,8 @@ class ThreadedServer:
         self.sock.bind((self.host, port))
 
         self.port = self.sock.getsockname()[1]
-        self.logger.debug("Self port: %d", self.port)
+        if port == 0:
+            self.logger.debug("Self port: %d", self.port)
 
         self.peers = self.options.get("suggested_peers", [])
         peers = self.tracker_manager.notify_start()
@@ -971,6 +972,49 @@ import Fiume.metainfo_decoder as md
 import bencodepy
 import argparse
 
+def parser(s=None):
+    parser = argparse.ArgumentParser()
+    parser.add_argument("torrent_path",
+                        type=pathlib.Path,
+                        help="path to .torrent file")
+
+    parser.add_argument("output_file",
+                        type=pathlib.Path,
+                        help="where to download the file")
+
+    parser.add_argument("-p", "--port",
+                        action="store",
+                        type=int,
+                        default=50146,
+                        help="port for this client")
+
+    parser.add_argument("-v", "--verbosity",
+                        action="count",
+                        default=0,
+                        dest="debug_level",
+                        help="debug level")
+
+    parser.add_argument("--suggested_peers",
+                        action="store",
+                        default=[],
+                        help="suggested_peers")
+
+    parser.add_argument("--delay",
+                        type=float,
+                        default=0,
+                        help="delay for every sent message (only debug)")
+
+    if s:
+        options = vars(parser.parse_args(s))
+    else:
+        options = vars(parser.parse_args())
+        
+    options["debug_level"] = utils.int_to_loglevel(options["debug_level"])
+    options["debug"] = False
+
+    return options
+
+
 if __name__ == "__main__":
     options = {
         "torrent_path": pathlib.Path("/home/groucho/torrent/image.jpg.torrent"),
